@@ -11,8 +11,15 @@ fn main() -> io::Result<()> {
     let handle = stdout.lock();
     let mut writer = fasta::Writer::new(handle);
 
-    let definition = fasta::record::Definition::new(String::from("sq0"), None);
-    let sequence = b"ACGT".iter().cycle().take(256).copied().collect();
+    let definition = fasta::record::Definition::new("sq0", None);
+    let sequence = fasta::record::Sequence::from(
+        b"ACGT"
+            .iter()
+            .cycle()
+            .take(256)
+            .copied()
+            .collect::<Vec<_>>(),
+    );
     let record = fasta::Record::new(definition, sequence);
 
     writer.write_record(&record)?;
